add method
Adds a new line of value at the current index and increments the index by one.
Implementation
void add(String value) {
_buffer.insert(index, value);
_index++;
}
Adds a new line of value at the current index and increments the index by one.
void add(String value) {
_buffer.insert(index, value);
_index++;
}