-
body
↔ String?
-
Optional body of the constructor.
getter/setter pair
-
className
→ String
-
The name of the class that is being constructed.
final
-
constant
↔ bool
-
Whether the constructor should be prefixed with
const.
getter/setter pair
-
factory
↔ bool
-
Whether the constructor should be prefixed with
factory.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
index
→ int
-
The current index of the cursor.
no setterinherited
-
name
↔ String?
-
Optional name of the constructor. Eg.
MyClass.name().
getter/setter pair
-
parameters
↔ List<Parameter>
-
The parameters included in this constructor.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
superCode
↔ String?
-
The optional value of the super constructor that will be appended
to this constructor.
getter/setter pair
-
tab
→ String
-
A tab used in this builder. Equivalent of
' ' * tabSize.
no setterinherited
-
tabCount
↔ int
-
How many tabs to append after each line. Default is 0.
getter/setter pairinherited
-
tabSize
↔ int
-
How many spaces does a tab contains. Default is 2.
getter/setter pairinherited